<?php
/**
* HTTP쥹ݥ󥹤åפ륯饹
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class Response extends Object
{
	private $_data;
	private $_status;

	/*
	 *    󥹥ȥ饯
	 */
	public function __construct()
	{
		parent::__construct();

		$this->_data = array();
	}

	/*
	 *    ơɤ
	 */
	public function getStatusCode()
	{
		return $this->_status;
	}

	/*
	 *    ơɤ
	 */
	public function setStatusCode( $status_code )
	{
		$this->_status = status_code;
	}

	/*
	 *    
	 */
	public function getKeys()
	{
		return array_keys( $this->_data );
	}

	/*
	 * 쥹ݥ󥹥ǡ
	 */
	public function get( $key )
	{
		return $this->_data[ $key ];
	}

	/*
	 * 쥹ݥ󥹥ǡ
	 */
	public function set( $key, $value )
	{
		$this->_data[ $key ] = $value;
	}

	/*
	 * 
	 */
	public function dump()
	{
		System::dumpArray( $this->_data );
	}

	/*
	 * ʸ
	 */
	public function __toString()
	{
		$str = "[Response]<BR>" . System::arrayToString( $this->_data );
		return $str;
	}
}
return __FILE__;
